import React, { useContext, useMemo, createContext, useEffect } from 'react';
var Suspense = React.Suspense;
var Context = createContext(); // Dangerously overwrite React.Suspense.
// Wrap original Suspense with a context provider.
// Context value is a set of callbacks.
// Each callback is invoked when Suspense component unmounts.

React.Suspense = function ReactPouchDBSuspenseCleanupContext(props) {
  var handlers = useMemo(function () {
    return new Set();
  }, []);
  useEffect(function () {
    return function () {
      return handlers.forEach(function (handler) {
        return handler();
      });
    };
  }, []);
  return React.createElement(Context.Provider, {
    value: handlers
  }, React.createElement(Suspense, props));
};

export default function useSuspenseContextCleanupHandlers() {
  return useContext(Context);
}
//# sourceMappingURL=useSuspenseContextCleanupHandlers.js.map